PaywallController class

Controlador para habilitar o deshabilitar el paywall en tiempo de ejecución.

Inheritance

Constructors

PaywallController()

Properties

enabled → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
disable() → void
Deshabilita el paywall y notifica a los oyentes.
dispose() → void
Discards any resources used by the object.
inherited
enable() → void
Habilita el paywall y notifica a los oyentes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited