PaywallOverlay class
Widget que superpone un efecto visual para recordar pagos vencidos.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PaywallOverlay
Constructors
- PaywallOverlay({Key? key, required Widget child, required DateTime dueDate, int daysDeadline = 60, PaywallEffect effect = PaywallEffect.gradient, Color color = const Color(0xFFFF0000), Color gradientFrom = const Color(0xFFFF0000), Color gradientTo = const Color(0xFF000000), bool enabled = true, bool blockInteractions = false, bool showMessage = true, String message = 'Pago pendiente', PaywallController? controller, bool recalculateOnMidnight = false})
-
const
Properties
- blockInteractions → bool
-
Si es verdadero, bloquea interacciones bajo el overlay.
final
- child → Widget
-
final
- color → Color
-
Color para el efecto sólido.
final
- controller → PaywallController?
-
Controlador opcional para controlar el estado en runtime.
final
- daysDeadline → int
-
Días para alcanzar la máxima intensidad del efecto.
final
- dueDate → DateTime
-
Fecha de vencimiento del pago.
final
- effect → PaywallEffect
-
Tipo de efecto visual a aplicar.
final
- enabled → bool
-
Si es falso, el efecto no se aplica.
final
- gradientFrom → Color
-
Color inicial del gradiente.
final
- gradientTo → Color
-
Color final del gradiente.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- message → String
-
Texto del mensaje a mostrar.
final
- recalculateOnMidnight → bool
-
Recalcula automáticamente al cruzar medianoche.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showMessage → bool
-
Muestra un mensaje centrado sobre el overlay.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PaywallOverlay> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited